toJson is the convention for a class to declare support for serialization to JSON. The implementation simply calls the private, generated helper method _$DayToJson.
toJson
_$DayToJson
Map<String, dynamic> toJson() => _$DayToJson(this);