HourSummary.fromJson constructor

HourSummary.fromJson(
  1. Map<String, dynamic> json
)

A necessary factory constructor for creating a new User instance from a map. Pass the map to the generated _$HourSummaryFromJson() constructor. The constructor is named after the source class, in this case, User.

Implementation

factory HourSummary.fromJson(Map<String, dynamic> json) =>
    _$HourSummaryFromJson(json);